==> tumblr_connect-7.x-1.0.tar.gz: tumblr_connect/tumblr-connect-followers-block.tpl.php <==
<?php

/**
 * @file
 * Default theme implementation to display a block.
 *
 * Available variables:
 * - $block->subject: Block title.
 * - $content: Block content.
 * - $block->module: Module that generated the block.
 * - $block->delta: An ID for the block, unique within each module.
 * - $block->region: The block region embedding the current block.
 * - $classes: String of classes that can be used to style contextually through
 *   CSS. It can be manipulated through the variable $classes_array from
 *   preprocess functions. The default values can be one or more of the following:
 *   - block: The current template type, i.e., "theming hook".
 *   - block-[module]: The module generating the block. For example, the user module
 *     is responsible for handling the default user navigation block. In that case
 *     the class would be "block-user".
 * - $title_prefix (array): An array containing additional output populated by
 *   modules, intended to be displayed in front of the main title tag that
 *   appears in the template.
 * - $title_suffix (array): An array containing additional output populated by
 *   modules, intended to be displayed after the main title tag that appears in
 *   the template.
 *
 * Helper variables:
 * - $classes_array: Array of html class attribute values. It is flattened
 *   into a string within the variable $classes.
 * - $block_zebra: Outputs 'odd' and 'even' dependent on each block region.
 * - $zebra: Same output as $block_zebra but independent of any block region.
 * - $block_id: Counter dependent on each block region.
 * - $id: Same output as $block_id but independent of any block region.
 * - $is_front: Flags true when presented in the front page.
 * - $logged_in: Flags true when the current user is a logged-in member.
 * - $is_admin: Flags true when the current user is an administrator.
 * - $block_html_id: A valid HTML ID and guaranteed unique.
 * - $follower_list: array of themed follower objects
 * - $list : use $list->getList() to access object array. Each element is an unthemed follower.
 * -- $follower->getName() : Outputs name of follower.
 * -- $follower->getUrl() : Outputs url of follower Tumbler page.
 * -- $follower->getImage() : Outputs url of followers image.
 * - $followers_table: A fully themed html display of tumblr followers (as set by block configure dialog)
 * - $numColumns: Number of table columns set in block configure dialog.
 * - $moreLink: Boolean flag. Sets whether there are more followers to display.
 * - $tumblr_url: Url of the synchronized remote tumblr page.
 * @see template_preprocess()
 * @see template_preprocess_block()
 * @see template_process()
 */
?>
<div <?php print $attributes; ?>>

  <?php print render($title_prefix); ?>

  <h2<?php print $title_attributes; ?></h2>

  <?php print render($title_suffix); ?>

  <div class="content"<?php print $content_attributes; ?>>

    <?php if ($followers_table): ?>

      <?php print $followers_table; ?>


    <?php endif; ?>
  </div>
</div>

==> tumblr_connect-7.x-1.3.tar.gz: tumblr_connect/tumblr-connect-followers-block.tpl.php <==
<?php

/**
 * @file
 * Default theme implementation to display a block.
 *
 * Available variables:
 * - $block->subject: Block title.
 * - $content: Block content.
 * - $block->module: Module that generated the block.
 * - $block->delta: An ID for the block, unique within each module.
 * - $block->region: The block region embedding the current block.
 * - $classes: String of classes that can be used to style contextually through
 *   CSS. It can be manipulated through the variable $classes_array from
 *   preprocess functions. The default values can be one or more of the following:
 *   - block: The current template type, i.e., "theming hook".
 *   - block-[module]: The module generating the block. For example, the user module
 *     is responsible for handling the default user navigation block. In that case
 *     the class would be "block-user".
 * - $title_prefix (array): An array containing additional output populated by
 *   modules, intended to be displayed in front of the main title tag that
 *   appears in the template.
 * - $title_suffix (array): An array containing additional output populated by
 *   modules, intended to be displayed after the main title tag that appears in
 *   the template.
 *
 * Helper variables:
 * - $classes_array: Array of html class attribute values. It is flattened
 *   into a string within the variable $classes.
 * - $block_zebra: Outputs 'odd' and 'even' dependent on each block region.
 * - $zebra: Same output as $block_zebra but independent of any block region.
 * - $block_id: Counter dependent on each block region.
 * - $id: Same output as $block_id but independent of any block region.
 * - $is_front: Flags true when presented in the front page.
 * - $logged_in: Flags true when the current user is a logged-in member.
 * - $is_admin: Flags true when the current user is an administrator.
 * - $block_html_id: A valid HTML ID and guaranteed unique.
 * - $follower_list: array of themed follower objects
 * - $list : use $list->getList() to access object array. Each element is an unthemed follower.
 * -- $follower->getName() : Outputs name of follower.
 * -- $follower->getUrl() : Outputs url of follower Tumbler page.
 * -- $follower->getImage() : Outputs url of followers image.
 * - $followers_table: A fully themed html display of tumblr followers (as set by block configure dialog)
 * - $numColumns: Number of table columns set in block configure dialog.
 * - $moreLink: Boolean flag. Sets whether there are more followers to display.
 * - $tumblr_url: Url of the synchronized remote tumblr page.
 * @see template_preprocess()
 * @see template_preprocess_block()
 * @see template_process()
 */
?>
<div <?php print $attributes; ?>>

  <?php print render($title_prefix); ?>

  <h2><?php print $title_attributes; ?></h2>

  <?php print render($title_suffix); ?>

  <div class="content"<?php print $content_attributes; ?>>

    <?php if ($followers_table): ?>

      <?php print $followers_table; ?>


    <?php endif; ?>
  </div>
</div>
